@@ -13,8 +13,7 @@ class Robolearn:
 
     def __init__(self, url='http://127.0.0.1:9000'):
         self.server = url
-        response = urllib2.urlopen('%s/api/info' % self.server)
-        self.info = json.loads(response.read())
+        self.__info()
 
     def forward(self):
         self.__server_rpc('forward')
@@ -22,6 +21,10 @@ class Robolearn:
     def rotate(self):
         self.__server_rpc('rotate')
 
+    def reset(self):
+        self.__server_rpc('reset')
+        self.__info()
+
     def before_obstacle(self):
         return self.info['before_obstacle']
 
@@ -32,3 +35,6 @@ class Robolearn:
         response = urllib2.urlopen('%s/api/%s' % (self.server, action))
         self.info = json.loads(response.read())
 
+    def __info(self):
+        response = urllib2.urlopen('%s/api/info' % self.server)
+        self.info = json.loads(response.read())
